@@ -1,7 +1,7 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.039';
+our $VERSION = '0.040';
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
@@ -187,7 +187,7 @@ sub startup {
   my $r = $app->routes;
 
   $r->any( '/' => sub { my $self = shift; $self->redirect_to( $self->home_page ) });
-  $r->any( '/page/:name' )->to('page#show');
+  $r->any( '/page/:name' )->to('page#show')->name('show_page');
   $r->post( '/login' )->to('user#login');
   $r->any( '/logout' )->to('user#logout');
 
@@ -197,7 +197,7 @@ sub startup {
   });
 
   $if_author->any( '/admin/menu' )->to('menu#edit');
-  $if_author->any( '/edit/:name' )->to('page#edit');
+  $if_author->any( '/edit/:name' )->to('page#edit')->name('edit_page');
   $if_author->websocket( '/store/page' )->to('page#store');
   $if_author->websocket( '/store/menu' )->to('menu#store');
   $if_author->websocket( '/files/list' )->to('file#list');
@@ -364,6 +364,10 @@ L<jQuery|http://jquery.com/> - because everything uses jQuery
 
 =item *
 
+L<html5sortable|https://github.com/voidberg/html5sortable> - Lightweight jQuery plugin to create sortable lists and grids using native HTML5 drag and drop API
+
+=item *
+
 L<HumaneJS|http://wavded.github.com/humane-js/> - A simple, modern, browser notification system
 
 =back
